@@ -4,9 +4,7 @@
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
 
-context("dbIsValid")
-
-source("utilities.R")
+context(paste(Sys.getenv("PRESTO_TYPE", "Presto"), "dbIsValid"))
 
 test_that("dbIsValid works with live database", {
   conn <- setup_live_connection()
@@ -29,7 +27,7 @@ test_that("dbIsValid works with live database", {
         dbFetch(result)
       }
     },
-    "Table.*__nonexistent_table__ does not exist"
+    "Table.*__nonexistent_table__.* does not exist"
   )
   expect_false(dbIsValid(result))
 
